@@ -2,18 +2,23 @@ use strict;
 use warnings;
 package Dist::Zilla::App::Command::clean;
 {
-  $Dist::Zilla::App::Command::clean::VERSION = '4.300014';
+  $Dist::Zilla::App::Command::clean::VERSION = '4.300015';
 }
 # ABSTRACT: clean up after build, test, or install
 use Dist::Zilla::App -command;
 
 
+sub opt_spec {
+  [ 'dry-run|n'   => 'don\'t actually remove anything, just show what would be done' ],
+}
+
+
 sub abstract { 'clean up after build, test, or install' }
 
 sub execute {
   my ($self, $opt, $arg) = @_;
 
-  $self->zilla->clean;
+  $self->zilla->clean($opt->dry_run);
 }
 
 1;
@@ -27,17 +32,23 @@ Dist::Zilla::App::Command::clean - clean up after build, test, or install
 
 =head1 VERSION
 
-version 4.300014
+version 4.300015
 
 =head1 SYNOPSIS
 
-  dzil clean
+  dzil clean [ --dry-run|-n ]
 
 This command removes some files that are created during build, test, and
 install.  It's a very thin layer over the C<L<clean|Dist::Zilla/clean>> method
 on the Dist::Zilla object.  The documentation for that method gives more
 information about the files that will be removed.
 
+=head1 OPTIONS
+
+=head2 -n, --dry-run
+
+Nothing is removed; instead, everything that would be removed will be listed.
+
 =head1 AUTHOR
 
 Ricardo SIGNES <rjbs@cpan.org>
