@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Dist::Zilla::App::Command::run;
 {
-  $Dist::Zilla::App::Command::run::VERSION = '4.300014';
+  $Dist::Zilla::App::Command::run::VERSION = '4.300015';
 }
 # ABSTRACT: run stuff in a dir where your dist is built
 use Dist::Zilla::App -command;
@@ -11,13 +11,20 @@ use Dist::Zilla::App -command;
 sub abstract { 'run stuff in a dir where your dist is built' }
 
 sub usage_desc {
-  return '%c %o run command [ arg1 arg2 ... ]';
+  return '%c %o [ run command [ arg1 arg2 ... ] ]';
 }
 
 sub execute {
   my ($self, $opts, $args) = @_;
 
-  $self->usage_error("no command to run supplied!") unless @$args;
+  unless (@$args) {
+    my $envname = $^O eq 'MSWin32' ? 'COMSPEC' : 'SHELL';
+    unless ($ENV{$envname}) {
+      $self->usage_error("no command supplied to run and no \$$envname set");
+    }
+    $args = [ $ENV{$envname} ];
+    $self->log("no command supplied to run so using \$$envname: $args->[0]");
+  }
 
   $self->zilla->run_in_build($args);
 }
@@ -33,7 +40,7 @@ Dist::Zilla::App::Command::run - run stuff in a dir where your dist is built
 
 =head1 VERSION
 
-version 4.300014
+version 4.300015
 
 =head1 SYNOPSIS
 
@@ -62,6 +69,9 @@ A command returning with an non-zero error code will left the build directory
 behind for analysis, and C<dzil> will exit with a non-zero status.  Otherwise,
 the build directory will be removed and dzil will exit with status zero.
 
+If no run command is provided, a new default shell is invoked. This can be
+useful for testing your distribution as if it were installed.
+
 =head1 AUTHOR
 
 Ricardo SIGNES <rjbs@cpan.org>
