@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::MakeMaker;
 {
-  $Dist::Zilla::Plugin::MakeMaker::VERSION = '4.300014';
+  $Dist::Zilla::Plugin::MakeMaker::VERSION = '4.300015';
 }
 
 # ABSTRACT: build a Makefile.PL that uses ExtUtils::MakeMaker
@@ -243,7 +243,7 @@ has __write_makefile_args => (
 __PACKAGE__->meta->make_immutable;
 1;
 
-__END__
+
 =pod
 
 =head1 NAME
@@ -252,7 +252,7 @@ Dist::Zilla::Plugin::MakeMaker - build a Makefile.PL that uses ExtUtils::MakeMak
 
 =head1 VERSION
 
-version 4.300014
+version 4.300015
 
 =head1 DESCRIPTION
 
@@ -277,6 +277,16 @@ set.
 
 You probably won't need to set this option.
 
+=head1 SEE ALSO
+
+Core Dist::Zilla plugins:
+L<@Basic|Dist::Zilla::PluginBundle::Basic>,
+L<ModuleBuild|Dist::Zilla::Plugin::ModuleBuild>,
+L<Manifest|Dist::Zilla::Plugin::Manifest>.
+
+Dist::Zilla roles:
+L<BuildRunner>, L<InstallTool>, L<PrereqSource>, L<TestRunner>.
+
 =head1 AUTHOR
 
 Ricardo SIGNES <rjbs@cpan.org>
@@ -290,3 +300,6 @@ the same terms as the Perl 5 programming language system itself.
 
 =cut
 
+
+__END__
+
