@@ -1,6 +1,6 @@
 package Dist::Zilla::PluginBundle::Filter;
 {
-  $Dist::Zilla::PluginBundle::Filter::VERSION = '4.300014';
+  $Dist::Zilla::PluginBundle::Filter::VERSION = '4.300015';
 }
 # ABSTRACT: use another bundle, with some plugins removed
 use Moose;
@@ -67,26 +67,32 @@ Dist::Zilla::PluginBundle::Filter - use another bundle, with some plugins remove
 
 =head1 VERSION
 
-version 4.300014
+version 4.300015
 
 =head1 SYNOPSIS
 
 In your F<dist.ini>:
 
   [@Filter]
-  -bundle = @Classic
-  -remove = PodVersion
-  -remove = Manifest
-  option = for_classic
+  -bundle = @Basic
+  -remove = ShareDir
+  -remove = UploadToCPAN
+  option = for_basic
 
 =head1 DESCRIPTION
 
-This plugin bundle actually wraps and modified another plugin bundle.  It
+This plugin bundle actually wraps and modifies another plugin bundle.  It
 includes all the configuration for the bundle named in the C<-bundle> attribute,
 but removes all the entries whose package is given in the C<-remove> attributes.
 
 Options not prefixed with C<-> will be passed to the bundle to be filtered.
 
+=head1 SEE ALSO
+
+Core Dist::Zilla plugins: L<@Basic|Dist::Zilla::PluginBundle::Basic>.
+
+Dist::Zilla roles: L<PluginBundle|Dist::Zilla::Role::PluginBundle>.
+
 =head1 AUTHOR
 
 Ricardo SIGNES <rjbs@cpan.org>
