@@ -1,6 +1,6 @@
 package Dist::Zilla::Role::PluginBundle::Easy;
 {
-  $Dist::Zilla::Role::PluginBundle::Easy::VERSION = '4.300014';
+  $Dist::Zilla::Role::PluginBundle::Easy::VERSION = '4.300015';
 }
 # ABSTRACT: something that bundles a bunch of plugins easily
 # This plugin was originally contributed by Christopher J. Madsen
@@ -97,7 +97,11 @@ sub add_bundle {
   my $package = _bundle_class($bundle);
   $payload  ||= {};
 
-  Class::MOP::load_class($package);
+  my $load_opts = {};
+  if( my $v = $payload->{':version'} ){
+    $load_opts->{'-version'} = $v;
+  }
+  Class::MOP::load_class($package, $load_opts);
 
   $bundle = "\@$bundle" unless $bundle =~ /^@/;
 
@@ -142,7 +146,7 @@ Dist::Zilla::Role::PluginBundle::Easy - something that bundles a bunch of plugin
 
 =head1 VERSION
 
-version 4.300014
+version 4.300015
 
 =head1 SYNOPSIS
 
